/**
 * BLOCK: line-grid
 *
 * Registering a basic block with Gutenberg.
 * Simple block, renders and saves the same content without any interactivity.
 */

//  Import CSS.
import './style.scss';
import './editor.scss';

import getIcon from '../_utils/get-icon';

const {
  __
} = wp.i18n; // Import __() from wp.i18n
const {
  Component
} = wp.element;
const {
  registerBlockType
} = wp.blocks;
const {
  RichText,
  InspectorControls,
  PanelColorSettings,
  MediaUpload,
} = wp.editor;

const {
  Button,
  PanelBody,
  SelectControl,
  ServerSideRender,
  TextControl
} = wp.components;
const el = wp.element.createElement;
const iconEl = el('svg', { width: 20, height: 20 },
  el('path', { fill: "#89cff5", d: "M0-1.46h22V4H0z" } )
);

class FullBlock1Inspector extends Component {
  constructor(props) {
    super(...arguments);
  }

  render() {
    const sortedbyoptions = gumblock.post_sort_by;

    const CategoryFilter = gumblock.categories;

    if (typeof this.props.attributes.block_id == 'undefined') {
      var new_block_id = Math.floor(Math.random() * 99999) + 999;
      this.props.attributes.block_id = new_block_id.toString();
    } else if (this.props.attributes.block_id.length < 1) {
      var new_block_id = Math.floor(Math.random() * 99999) + 999;
      this.props.attributes.block_id = new_block_id.toString();
    }
    const {
      setAttributes,
      attributes: {
        gum_grid_title,
        gum_grid_title_link,
        post_sort_by,
        gum_post_offset,
        category_id,
        post_type_filter,
        tag_filter,
        author_filter,
        multi_cat_filter,
        block_id,

      }
    } = this.props;
    return (
      <InspectorControls key="inspector">
            
      <PanelBody 
      title={ __( 'General' ) } 
      initialOpen={ false }
      >
      
      <TextControl
      title ={ __('Title')}
      label={ __( 'Title' ) }
      name = { __('gum_grid_title')}
      placeholder={__('Enter Title')}
      value={ gum_grid_title }
      onChange={ ( value ) => this.props.setAttributes( { gum_grid_title: value } ) }

      /> 
      
      <TextControl
      title ={ __('Title Link')}
      label={ __( 'Optional title url' ) }
      name = { __('gum_grid_title_link')}
      placeholder={__('title url')}
      value={ gum_grid_title_link }
      onChange={ ( value ) => this.props.setAttributes( { gum_grid_title_link: value } ) }
      /> 

      <SelectControl
      label={ __( 'Sort by' ) }
      description={ __( 'Sorts posts' ) }
      options={ sortedbyoptions }
      value={ post_sort_by }
      name= { __('post_sort_by')}
      onChange={ ( value ) => this.props.setAttributes( { post_sort_by: value } ) }
      />
      
      <TextControl
      title ={ __('Offset Post')}
      label={ __( 'Offset Post' ) }
      placeholder={ __('Enter Offset Post')}
      name ={ __('gum_post_offset')}
      value={ gum_post_offset }
      onChange={ ( value ) => this.props.setAttributes( { gum_post_offset: value } ) }

      /> 
      
      </PanelBody>
      <PanelBody 
      title={ __( 'Filter' ) } 
      initialOpen={ false }
      >
      <SelectControl
      label={ __( 'Category Filter' ) }
      description={ __( 'Show posts from only this category' ) }
      options={ CategoryFilter }
      name ={ 'category_id'}
      value={ category_id }
      onChange={ ( value ) => this.props.setAttributes( { category_id: value } ) }
      />
      
      
      <TextControl
      title ={ __('Multiple Category Filter')}
      label={ __( 'Multiple Category Filter' ) }
      placeholder={ __('Multiple Category Filter')}
      name ={ __('multi_cat_filter')}
      value={ multi_cat_filter }
      onChange={ ( value ) => this.props.setAttributes( { multi_cat_filter: value } ) }
      
      /> 
      
      <TextControl
      title ={ __('Tag Filter')}
      label={ __( 'Tag  Filter' ) }
      placeholder={ __('Tag Filter')}
      name ={ __('multi_tag_filter')}
      value={ tag_filter }
      onChange={ ( value ) => this.props.setAttributes( { tag_filter: value } ) }
      /> 
      
      <TextControl
      title ={ __('Author Filter')}
      label={ __( 'Author  Filter' ) }
      placeholder={ __('Author Filter')}
      name ={ __('multi_author_filter')}
      value={ author_filter }
      onChange={ ( value ) => this.props.setAttributes( { author_filter: value } ) }
      /> 


      <TextControl
      title ={ __(' Post Type filter')}
      label={ __( ' Post Type filter' ) }
      placeholder={ __('Author Filter')}
      name ={ __('post_type_filter')}
      value={ post_type_filter }
      onChange={ ( value ) => this.props.setAttributes( { post_type_filter: value } ) }

      /> 

      </PanelBody>
      
      <PanelBody  title={ __( 'Extra' ) } 
      initialOpen={ false }>

      <TextControl
      title ={ __('Block id')}
      label={ __( 'Block id' ) }
      name = { __('block_id')}
      placeholder={__('Enter Title')}
      value={ block_id }
      onChange={ ( value ) => this.props.setAttributes( { block_id: value } ) }

      /> 

      </PanelBody>

      </InspectorControls>
      );
  }
}

class FullGrid1Edit extends Component {

  render() {

    const {
      attributes: {
        block_id,
        gum_grid_title,
        gum_grid_title_link,
        post_sort_by,
        gum_post_offset,
        category_id,
        post_type_filter,
        tag_filter,
        author_filter,
        multi_cat_filter,
      },
      setAttributes
    } = this.props;

    return [ <
      FullBlock1Inspector {
        ...{
          setAttributes,
          ...this.props
        }
      }
      />, <
      ServerSideRender
      block = "gum/line-grid"
      attributes = {
        this.props.attributes
      }

      />

    ];
  }
}


/**
 * Register: aa Gutenberg Block.
 */
registerBlockType('gum/line-grid', {

  title: __('Grid Line'), // Block title.
  //icon: getIcon('line-grid'), // Block icon from Dashicons → https://developer.wordpress.org/resource/dashicons/.
  icon:iconEl,
  category: 'gumtheme', // Block category — Group blocks together based on common traits E.g. common, formatting, layout widgets, embed.
  keywords: [
    __('Gumthemes - Grid Line'),
  ],

  attributes: {

    'gum_grid_title': {
      'type': 'string',
    },
    'gum_grid_title_link': {
      'type': 'string',
    },
    'post_sort_by': {
      'type': 'string',
    },

    'gum_post_offset': {
      'type': 'string',
    },
    'category_id': {
      'type': 'string',
    },
    ' tag_filter': {
      'type': 'string',
    },

    'author_filter': {
      'type': 'string',
    },
    'multi_cat_filter': {
      'type': 'string',
    },
    'block_id': {
      'type': 'string',
    },


  },
  edit: FullGrid1Edit,
  save: function (props) {
    return null;
  },
});
