/**
 * BLOCK: post-grid-3
 *
 * Registering a basic block with Gutenberg.
 * Simple block, renders and saves the same content without any interactivity.
 */

//  Import CSS.
import './style.scss';
import './editor.scss';

import getIcon from '../_utils/get-icon';

const { __ } = wp.i18n; // Import __() from wp.i18n
const { Component } = wp.element;
const { registerBlockType } = wp.blocks;
const {
  RichText,
  InspectorControls,
  PanelColorSettings,
  MediaUpload,
} = wp.editor;

const {
  Button,
  PanelBody,
  SelectControl,
  ServerSideRender,
  TextControl,
  ToggleControl
} = wp.components;

const el = wp.element.createElement;
const iconEl = el('svg', { width: 20, height: 20 },
  el('path', { fill: "#89cff5", d: "M0 0h10v15H0z M0 19h10v1H0z M0 17h7.5v1H0z M11 0h10v15H11z M11 19h10v1H11z M11 17h7.5v1H11z " } )
);

class PostBlock3Inspector extends Component {
  constructor( props ) {
    super( ...arguments );
  }

  render() {
    const sortedbyoptions = gumblock.post_sort_by;

    const CategoryFilter= gumblock.categories;

    const AjaxFilterType= gumblock.ajax_filter;

    const paginationsfilter = gumblock.pagination_filter_loadmore;

    const custom_date_type_data = gumblock.date_format;

        if (typeof this.props.attributes.block_id == 'undefined'){
            var new_block_id = Math.floor(Math.random() * 99999) + 999;
            this.props.attributes.block_id = new_block_id.toString();
        }
        else if(this.props.attributes.block_id.length < 1 ){
            var new_block_id = Math.floor(Math.random() * 99999) + 999;
            this.props.attributes.block_id = new_block_id.toString();
        }

        //if(typeof this.props.attributes.posts_per_page == 'undefined')  this.props.attributes.posts_per_page = 6;

          const { setAttributes, attributes: {
            gum_grid_title,
            gum_grid_title_link,
            posts_per_page,
            post_sort_by,
            gum_post_offset,
            category_id,
            post_type_filter,
            tag_filter,
            author_filter,
            gum_ajax_filter_type,
            ajax_cat_filter_default_text,
            ajax_cat_filter,
            gum_grid_pagination,
            multi_cat_filter,
            block_id,
            show_cat,
            show_author,
            show_views,
            show_likes,
            show_comment_count,
            show_reviews,
            show_date,
            date_type,

          }} = this.props;
          return (
            <InspectorControls key="inspector">

            <PanelBody
            title={ __( 'General' ) }
            initialOpen={ false }
            >

            <TextControl
            title ={ __('Title')}
            label={ __( 'Title' ) }
            name = { __('gum_grid_title')}
            placeholder={__('Enter Title')}
            value={ gum_grid_title }
            onChange={ ( value ) => this.props.setAttributes( { gum_grid_title: value } ) }

            />

            <TextControl
            title ={ __('Title Link')}
            label={ __( 'Optional title url' ) }
            name = { __('gum_grid_title_link')}
            placeholder={__('title url')}
            value={ gum_grid_title_link }
            onChange={ ( value ) => this.props.setAttributes( { gum_grid_title_link: value } ) }
            />

            <TextControl
            title ={ __('Number of posts to show')}
            label={ __( 'Post limit' ) }
            name = { __('posts_per_page')}
            placeholder={__('Number of posts to show')}
            value={ posts_per_page }
            onChange={ ( value ) => this.props.setAttributes( { posts_per_page: value } ) }
            />


            <SelectControl
            label={ __( 'Sort by' ) }
            description={ __( 'Sorts posts' ) }
            options={ sortedbyoptions }
            value={ post_sort_by }
            name= { __('post_sort_by')}
            onChange={ ( value ) => this.props.setAttributes( { post_sort_by: value } ) }
            />

            <TextControl
            title ={ __('Offset Post')}
            label={ __( 'Offset Post' ) }
            placeholder={ __('Enter Offset Post')}
            name ={ __('gum_post_offset')}
            value={ gum_post_offset }
            onChange={ ( value ) => this.props.setAttributes( { gum_post_offset: value } ) }

            />

            </PanelBody>
            <PanelBody
            title={ __( 'Filter' ) }
            initialOpen={ false }
            >
            <SelectControl
            label={ __( 'Category Filter' ) }
            description={ __( 'Show posts from only this category' ) }
            options={ CategoryFilter }
            name ={ 'category_id'}
            value={ category_id }
            onChange={ ( value ) => this.props.setAttributes( { category_id: value } ) }
            />


            <TextControl
            title ={ __('Multiple Category Filter')}
            label={ __( 'Multiple Category Filter' ) }
            placeholder={ __('Multiple Category Filter')}
            name ={ __('multi_cat_filter')}
            value={ multi_cat_filter }
            onChange={ ( value ) => this.props.setAttributes( { multi_cat_filter: value } ) }

            />

            <TextControl
            title ={ __('Tag Filter')}
            label={ __( 'Tag  Filter' ) }
            placeholder={ __('Tag Filter')}
            name ={ __('multi_tag_filter')}
            value={ tag_filter }
            onChange={ ( value ) => this.props.setAttributes( { tag_filter: value } ) }
            />

            <TextControl
            title ={ __('Author Filter')}
            label={ __( 'Author  Filter' ) }
            placeholder={ __('Author Filter')}
            name ={ __('multi_author_filter')}
            value={ author_filter }
            onChange={ ( value ) => this.props.setAttributes( { author_filter: value } ) }
            />


            <TextControl
            title ={ __(' Post Type filter')}
            label={ __( ' Post Type filter' ) }
            placeholder={ __('Author Filter')}
            name ={ __('post_type_filter')}
            value={ post_type_filter }
            onChange={ ( value ) => this.props.setAttributes( { post_type_filter: value } ) }

            />


            </PanelBody>

            <PanelBody  title={ __( 'Ajax Filter' ) }
            initialOpen={ false }>

            <SelectControl
            title = { __('Ajax Filter Type')}
            label ={ __('Show date on gird?')}
            options={AjaxFilterType}
            name= { __('gum_ajax_filter_type')}
            value={ gum_ajax_filter_type }
            onChange={ ( value ) => this.props.setAttributes( { gum_ajax_filter_type: value } ) }

            />


            <TextControl
            title ={ __('Ajax Filter Categories')}
            label = { __('Filter multiple categories by ID, enter comma separated category IDs (1,2,3)')}
            name = { __('ajax_cat_filter')}
            value={ ajax_cat_filter }
            onChange={ ( value ) => this.props.setAttributes( { ajax_cat_filter: value } ) }
            />


            <TextControl
            label ={ __('Ajax Filter Default text')}
            name = { __('ajax_cat_filter_default_text')}
            value={ ajax_cat_filter_default_text }
            onChange={ ( value ) => this.props.setAttributes( { ajax_cat_filter_default_text: value } ) }

            />
            </PanelBody>

            <PanelBody  title={ __( 'Pagination' ) }
            initialOpen={ false }>

            <SelectControl
            label = { __('Pagination')}
            options={paginationsfilter}
            value={ gum_grid_pagination }
            name= { __('gum_grid_pagination')}

            onChange={ ( value ) => this.props.setAttributes( { gum_grid_pagination: value } ) }

            />
            </PanelBody>
            <PanelBody
      title={ __( 'Display' ) }
      initialOpen={ false }
      >
        <ToggleControl
          label={ __( 'Category' ) }
          checked={ !! show_cat }
          onChange={ () => this.props.setAttributes( {  show_cat : ! show_cat } ) }
         help={ !! show_cat ? __( 'Show Category' ) : __( 'Hide category.' ) }
        />
         <ToggleControl
          label={ __( 'Author' ) }
          checked={ !! show_author }
          onChange={ () => this.props.setAttributes( {  show_author : ! show_author } ) }
         help={ !! show_author ? __( 'Show Author' ) : __( 'Hide Author.' ) }
        />
         <ToggleControl
          label={ __( 'Views' ) }
          checked={ !! show_views }
          onChange={ () => this.props.setAttributes( {  show_views : ! show_views } ) }
         help={ !! show_views ? __( 'Show Views' ) : __( 'Hide Views.' ) }
        />
         <ToggleControl
          label={ __( 'Likes' ) }
          checked={ !! show_likes }
          onChange={ () => this.props.setAttributes( {  show_likes : ! show_likes } ) }
         help={ !! show_likes ? __( 'Show Likes' ) : __( 'Hide Likes.' ) }
        />
         <ToggleControl
          label={ __( 'Comment Count' ) }
          checked={ !! show_comment_count }
          onChange={ () => this.props.setAttributes( {  show_comment_count : ! show_comment_count } ) }
         help={ !! show_comment_count ? __( 'Show Comment Count' ) : __( 'Hide Comment Count.' ) }
        />
        <ToggleControl
          label={ __( 'Reviews' ) }
          checked={ !! show_reviews }
          onChange={ () => this.props.setAttributes( {  show_reviews : ! show_reviews } ) }
         help={ !! show_reviews ? __( 'Show Reviews' ) : __( 'Hide Reviews.' ) }
        />
         <ToggleControl
          label={ __( 'Date' ) }
          checked={ !! show_date }
          onChange={ () => this.props.setAttributes( {  show_date : ! show_date } ) }
         help={ !! show_date ? __( 'Show date' ) : __( 'Hide date.' ) }
        />

        <SelectControl
          label={ __( 'Date Type' ) }
          options={ custom_date_type_data }
          name ={ 'date_type'}
          value={ date_type }
          onChange={ ( value ) => this.props.setAttributes( { date_type: value } ) }
        />
      </PanelBody>
            <PanelBody  title={ __( 'Extra' ) }
            initialOpen={ false }>

            <TextControl
            title ={ __('Block id')}
            label={ __( 'Block id' ) }
            name = { __('block_id')}
            placeholder={__('Enter Title')}
            value={ block_id }
            onChange={ ( value ) => this.props.setAttributes( { block_id: value } ) }

            />

            </PanelBody>

            </InspectorControls>
            );
}
}

class PostBlock3Edit extends Component {

  render() {

    const {
      attributes: {
        block_id,
        gum_grid_title,
        gum_grid_title_link,
        posts_per_page,
        post_sort_by,
        gum_post_offset,
        category_id,
        post_type_filter,
        tag_filter,
        author_filter,
        multi_cat_filter,
        gum_ajax_filter_type,
        ajax_cat_filter_default_text,
        ajax_cat_filter,
        pagination_filter,
        show_cat,
        show_author,
        show_views,
        show_likes,
        show_comment_count,
        show_reviews,
        show_date,
        date_type,
      },
      setAttributes
    } = this.props;

    return[
    <PostBlock3Inspector
    { ...{ setAttributes, ...this.props } }
    />,
    <ServerSideRender
    block="gum/post-grid-3"
    attributes={this.props.attributes}

    />

    ];
  }
}



/**
 * Register: aa Gutenberg Block.
 */
 registerBlockType( 'gum/post-grid-3', {

  title: __( 'Post Grid 3' ), // Block title.
	icon: iconEl, // Block icon from Dashicons → https://developer.wordpress.org/resource/dashicons/.
	category: 'gumtheme', // Block category — Group blocks together based on common traits E.g. common, formatting, layout widgets, embed.
	keywords: [
  __( 'Gumthemes - Post Grid 3' ),
  ],

  attributes: {

    'gum_grid_title' : {
      'type' : 'string',
    },
    'gum_grid_title_link' : {
      'type' : 'string',
    },
    'posts_per_page' : {
      'type' : 'string',
    },
    'post_sort_by' : {
      'type' : 'string',
    },

    'gum_post_offset' : {
      'type' : 'string',
    },
    'category_id' : {
      'type' : 'string',
    },
    ' tag_filter' : {
      'type' : 'string',
    },

    'author_filter' : {
      'type' : 'string',
    },
    'multi_cat_filter' : {
      'type' : 'string',
    },
    'gum_ajax_filter_type' : {
      'type' : 'string',
    },

    'ajax_cat_filter_default_text' : {
      'type' : 'string',
    },

    'ajax_cat_filter' : {
      'type' : 'string',
    },

    'gum_grid_pagination' : {
      'type' : 'string',
    },
    'block_id' : {
      'type' : 'string',
    },
    'show_cat': {
      'type': 'boolean',
			'default': true,
    },
    'show_author': {
      'type': 'boolean',
			'default': true,
    },
    'show_views': {
      'type': 'boolean',
			'default': true,
    },
    'show_likes': {
      'type': 'boolean',
			'default': true,
    },
    'show_comment_count': {
      'type': 'boolean',
			'default': true,
    },
    'show_reviews': {
      'type': 'boolean',
      'default': false,
    },
    'show_date': {
      'type': 'boolean',
			'default': true,
    },
    'date_type': {
      'type': 'string',
    },


  },
  edit: PostBlock3Edit,

  save: function( props ) {
    return null;
  },
} );
