/**
 * BLOCK: sidebar
 *
 * Registering a basic block with Gutenberg.
 * Simple block, renders and saves the same content without any interactivity.
 */

//  Import CSS.
import './style.scss';
import './editor.scss';

import getIcon from '../_utils/get-icon';

const { __ } = wp.i18n; // Import __() from wp.i18n
const { Component } = wp.element;
const { registerBlockType } = wp.blocks;
const {
  RichText,
  InspectorControls,
  PanelColorSettings,
  MediaUpload,
} = wp.editor;

const {
  Button,
  PanelBody,
  SelectControl,
  ServerSideRender,
  TextControl
} = wp.components;


const el = wp.element.createElement;
const iconEl = el('svg', { width: 20, height: 20 },
  el('path', { fill: "#89cff5", d: "M0 0h18v1.18H0z M2 3h3v1.18H2z M6 3h3v1.18H6z M0 1h1v19H0z M18 0h1v20H18z M0 19h18v1.18H0z M11 2h5v3.53h-5z M11 7.49h5v3.53h-5z M11 12.98h5v3.53h-5z" } )
);

class SidebarInspector extends Component {
  constructor( props ) {
    super( ...arguments );
  }

  render() {        
    const sortedbyoptions = gumblock.post_sort_by;
    
    const CategoryFilter= gumblock.categories;
    
    const AjaxFilterType= gumblock.ajax_filter; 
    
    const paginationsfilter = gumblock.pagination_filter_next_prev;

    const selectsidebaroptions= gumblock.registeredsidebars;

        if (typeof this.props.attributes.block_id == 'undefined'){
            var new_block_id = Math.floor(Math.random() * 99999) + 999;
            this.props.attributes.block_id = new_block_id.toString();
        }
        else if(this.props.attributes.block_id.length < 1 ){
            var new_block_id = Math.floor(Math.random() * 99999) + 999;
            this.props.attributes.block_id = new_block_id.toString();
        }
          const { setAttributes, attributes: { 
            gum_grid_title,
            gum_grid_title_link,
            post_sort_by,
            gum_post_offset,
            category_id,
            select_sidebar,
            post_type_filter,
            tag_filter,
            author_filter,
            gum_ajax_filter_type,
            ajax_cat_filter_default_text,
            ajax_cat_filter,
            gum_grid_pagination,
            multi_cat_filter,
            block_id,
            
          }} = this.props;

          //console.log(selectsidebaroptions);

          return (
            <InspectorControls key="inspector">
            
            <PanelBody>
                <SelectControl
                label={ __( 'Select Sidebar' ) }
                description={ __( 'Select Sidebar' ) }
                options={ selectsidebaroptions }
                //options={ CategoryFilter }
                name= { __('select_sidebar')}
                value={ select_sidebar }             
                onChange={ ( value ) => this.props.setAttributes( { select_sidebar: value } ) }            
                />
            </PanelBody>

            </InspectorControls>
            );
}
}

class SidebarEdit extends Component {

  render() {

    const {
      attributes: {
        block_id,
        gum_grid_title,
        gum_grid_title_link,
        post_sort_by,
        gum_post_offset,
        select_sidebar,
        category_id,
        post_type_filter,
        tag_filter,
        author_filter,
        multi_cat_filter,
        gum_ajax_filter_type,
        ajax_cat_filter_default_text,
        ajax_cat_filter,
        pagination_filter,
      },
      setAttributes
    } = this.props;

    return[
    <SidebarInspector
    { ...{ setAttributes, ...this.props } }
    />,
    <ServerSideRender
    block="gum/sidebar-1"
    attributes={this.props.attributes}    
    />   
    ];
  }
}



/**
 * Register: aa Gutenberg Block.
 */
 registerBlockType( 'gum/sidebar-1', {
    
    title: __( 'Sidebar' ), // Block title.
	icon: iconEl, // Block icon from Dashicons → https://developer.wordpress.org/resource/dashicons/.
	category: 'gumtheme', // Block category — Group blocks together based on common traits E.g. common, formatting, layout widgets, embed.
	keywords: [
  __( 'Gumthemes - Sidebar' ),
  ],

  attributes: {
    
    'gum_grid_title' : {
      'type' : 'string',
    },
    'gum_grid_title_link' : {
      'type' : 'string',
    },
    'post_sort_by' : {
      'type' : 'string',
    },
    
    'gum_post_offset' : {
      'type' : 'string',
    },
    'select_sidebar' : {
      'type' : 'string',
    },
    'category_id' : {
      'type' : 'string',
    },
    ' tag_filter' : {
      'type' : 'string',
    },

    'author_filter' : {
      'type' : 'string',
    },
    'multi_cat_filter' : {
      'type' : 'string',
    },
    'gum_ajax_filter_type' : {
      'type' : 'string',
    },

    'ajax_cat_filter_default_text' : {
      'type' : 'string',
    },

    'ajax_cat_filter' : {
      'type' : 'string',
    },

    'gum_grid_pagination' : {
      'type' : 'string',
    },
    'block_id' : {
      'type' : 'string',
    },

    
  },
  edit: SidebarEdit,

  save: function( props ) {
    return null;
  },
} );
