<?php
/**
 * square functions and definitions
 *
 * @package square
 */

 define( 'THEMENAME', 'square' );
 define( 'THEMEVER', '1.0.0' );
 define( 'GUM_THEME_URL', get_template_directory_uri() );
 define( 'GUM_THEME_PATH', get_template_directory() );



require_once GUM_THEME_PATH . '/framework/includes/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'gum_register_required_plugins' );


$blog_grid = 0;
global $gumtheme_options;


if(empty($gumtheme_options) && defined('GUM_THEME_OPTIONS_KEY')){
	$gumtheme_options = get_option(GUM_THEME_OPTIONS_KEY);
	// if theme option is not set yet, set default options.
	if(!is_array($gumtheme_options)){
		global $default_theme_options;
		$gumtheme_options = $default_theme_options;
	}
}
global $gumtheme_translations;
if(empty($gumtheme_translations) && defined('GUM_THEME_TRANS_KEY')){
	$gumtheme_translations = get_option(GUM_THEME_TRANS_KEY);
}

require(get_template_directory() . '/framework/init.php');

if ( ! function_exists( 'square_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function square_setup() {

	remove_filter('the_content', 'wpautop');

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on square, use a find and replace
	 * to change 'square' to the name of your theme in all the template files
	 */


	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
    'slidein' => esc_html__( 'Slidein Bar Menu', 'focus-gumtheme' ),
		'primary' => esc_html__( 'Primary Menu', 'square' ),
		'footer' => esc_html__( 'Footer Menu', 'square' ),
		'mobilemenu' => esc_html__( 'Mobile Menu', 'square' ),

	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );


	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on square, use a find and replace
	 * to change 'square' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'square', get_template_directory() . '/languages' );


	/*
		 * Enable support for Post Formats.
		 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'video',
	) );

	/**
	* Image sizes
	* https://developer.wordpress.org/reference/functions/add_image_size/
	**/

	//used in theme
	add_image_size('gum_450X550', 450, 550, array( 'center', 'top' ));

	add_image_size('gum_700X450', 700, 450, array( 'center', 'top' ));

	add_image_size('gum_700X300', 700, 300, array( 'center', 'top' ));

	add_image_size('gum_170X170', 170, 170, array( 'center', 'top' ));

	add_image_size('gum_350X380', 350, 380, array( 'center', 'top' ));

	//framework essentials
	add_image_size('gum_780X468', 780, 468, array( 'center', 'top' ));

	add_image_size('gum_600X360', 600, 360, array( 'center', 'top' ));

	add_image_size('gum_300X180', 300, 180, array( 'center', 'top' ));

	add_image_size('gum_400X240', 400, 240, array( 'center', 'top' ));

	add_image_size('gum_350X210', 350, 210, array( 'center', 'top' ));

	add_image_size('gum_150X90', 150, 90, array( 'center', 'top' ));

}
endif; // square_setup
add_action( 'after_setup_theme', 'square_setup' );



/*
	* Editor style
*/
add_editor_style( get_template_directory_uri()  .'/css/custom-editor-style.css' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function square_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'square_content_width', 640 );
}
add_action( 'after_setup_theme', 'square_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
function square_scripts() {

	$version = rand();

	wp_enqueue_style( 'font-awesome', get_template_directory_uri()."/assets/font-awesome/css/font-awesome.min.css" );

	wp_enqueue_style( 'square-main-css', get_template_directory_uri()."/css/main/style.css", "", $version );
	wp_enqueue_style( 'square-style', get_stylesheet_uri(), "", $version );

	// Load google fonts
	if(defined('GUM_THEME_GOOGLEFONT')) $googlefonts = get_option(GUM_THEME_GOOGLEFONT);

	if(!empty($googlefonts)){
		$Gfonts = implode("|", $googlefonts);
		wp_register_style('googleFonts-custom', 'https://fonts.googleapis.com/css?family='.$Gfonts);
		wp_enqueue_style( 'googleFonts-custom');
	}

	// enqueue custom css
	if(defined('GUM_ASSETS_DIR') && defined('GUM_CUSTOM_CSS_FILE') && file_exists(GUM_ASSETS_DIR.'/'.GUM_CUSTOM_CSS_FILE)){

		wp_enqueue_style( 'gum-custom-style', GUM_ASSETS_URL."/".GUM_CUSTOM_CSS_FILE, "", $version);

		// if file exists, delete custom css option to aviod having duplicate rules.
		//delete_option(GUM_CUSTOM_CSS_OPTION);
	}

	if(defined('GUM_ASSETS_DIR') && defined('GUM_CAT_CSS_FILE') && file_exists(GUM_ASSETS_DIR.'/'.GUM_CAT_CSS_FILE)){
		wp_enqueue_style( 'gum-custom-cat', GUM_ASSETS_URL."/".GUM_CAT_CSS_FILE, "", $version );
	}
	wp_enqueue_script( 'jquery');

	wp_enqueue_script( 'square-navigation', get_template_directory_uri() . '/js/main/main.js', array(), $version, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	//............Theme Styles and scripts
  //wp_enqueue_style( 'googleFonts', 'https://fonts.googleapis.com/css?family=open+sans|Oswald');

	wp_enqueue_style( 'theme-fonts', 'https://fonts.googleapis.com/css?family=Open+Sans:300,400,600,700,800|Roboto+Slab:100,300,400,700&display=swap', false );

	//wp_enqueue_script( 'bootstrap-javascript',get_template_directory_uri().'/assets/js/vendor/bootstrap.min.js' );

}
add_action( 'wp_enqueue_scripts', 'square_scripts' );
if(defined('GUM_CUSTOM_CSS_OPTION') && get_option(GUM_CUSTOM_CSS_OPTION, true)){
	//dd("Insert css in header");
	add_action( 'wp_head', function () {
		echo '<style type="text/css" id="gum_custom_css">'.get_option(GUM_CUSTOM_CSS_OPTION, true).'</style>';
	});
}

function gum_editor_assets() { // phpcs:ignore

	// Styles.
	wp_enqueue_style(
		'gum-square-block-editor-css', // Handle.
		get_template_directory_uri()."/css/main/style.css",
		array( 'wp-edit-blocks' ) // Dependency to include the CSS after it.
		// filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
	);
}

// Hook: Editor assets.
add_action( 'enqueue_block_editor_assets', 'gum_editor_assets' );
function gumtheme_widgets_init()
{
	if(function_exists("gum_sidebars")) $sidebars = gum_sidebars();
	if(!empty($sidebars)){
		foreach($sidebars as $sidebar){
		    register_sidebar( array(
				'name'          => esc_html__( $sidebar['name'], 'gumtheme' ),
				'id'            => $sidebar['id'],
				'description'   => '',
				'before_widget' => '<'.$sidebar['tag'].' id="%1$s" class="widget '.$sidebar['wrapper_class'].' %2$s">',
				'after_widget'  => '</'.$sidebar['tag'].'>',
				'before_title'  => '<h4 class="widget-title '.$sidebar['title_class'].'">',
				'after_title'   => '</h4>',
			) );
		}
	}

}
add_action('widgets_init', 'gumtheme_widgets_init');

function new_excerpt_more( $more ) {
	return ' ...';
}
add_filter('excerpt_more', 'new_excerpt_more');


add_filter( 'pre_get_posts', 'gum_archive_per_page' );

function gum_archive_per_page( $query ) {
	// if gumtheme plugin disabled, return.
	if(!class_exists('Gum_html')) return '';
	global $gumtheme_options;
	if ( is_archive()  ) {

	    $obj = get_queried_object();
	    $cat_id = '';
		if(!empty($obj->term_id)) $cat_id = $obj->term_id;

		$cat_option = Gum_html::get_cat_options($cat_id);
		if(!empty($cat_option['show_cat_top_post_grid'])) $show_cat_top_post_grid = $cat_option['show_cat_top_post_grid'];
		if($show_cat_top_post_grid == 'default' && !empty($gumtheme_options['show_cat_top_post_grid'])) $show_cat_top_post_grid = $gumtheme_options['show_cat_top_post_grid'];

        if ( !empty($cat_id) && ! is_admin() && $query->is_main_query() && ! $query->get( 'cat' ) && $show_cat_top_post_grid != 'no') {

			$options = array(
				"posts_per_page" => '5',
				"category" => $cat_id,
			 );
			$posts_array = get_posts( $options );

			$post_exclude = array();

			if(!empty($posts_array)) foreach($posts_array as $posts_arr) $post_exclude[] = $posts_arr->ID;

	        $query->set( 'post__not_in', $post_exclude );

	    }
    }
    // blog page
    if(is_home()){

	    $blog_global_settings = Gum_html::get_theme_post_options();

		if(!empty($blog_global_settings['show_blog_top_post_grid']))$show_top_post_grid = $blog_global_settings['show_blog_top_post_grid'];

        if (! is_admin() && $query->is_main_query() && ($show_top_post_grid == 'yes' || $show_top_post_grid == 1)) {

			$options = array(
				"posts_per_page" => '5',
			 );
			 $posts_array = get_posts( $options );

			 $post_exclude = array();
			if(!empty($posts_array)){
				 foreach($posts_array as $posts_arr) $post_exclude[] = $posts_arr->ID;
			}
	        $query->set( 'post__not_in', $post_exclude );

	    }
    }
}
/**
* Favicon
*/
add_action( 'wp_head', 'gum_add_favicon_markups',1,1);
function gum_add_favicon_markups(){

	global $gumtheme_options;

	if(!empty($gumtheme_options['favicon'])) echo "<link rel='shortcut icon' href='".$gumtheme_options['favicon']."' type='image/x-icon' />\n";
	if(!empty($gumtheme_options['apple_iphone_icon'])) echo "<link rel='apple-touch-icon' href='".$gumtheme_options['apple_iphone_icon']."'/>\n";
	if(!empty($gumtheme_options['apple_iphone_plus_icon'])) echo "<link rel='apple-touch-icon' sizes='180x180' href='".$gumtheme_options['apple_iphone_plus_icon']."'/>\n";
	if(!empty($gumtheme_options['apple_ipad_retina_icon'])) echo "<link rel='apple-touch-icon' sizes='152x152' href='".$gumtheme_options['apple_ipad_retina_icon']."'/>\n";
	if(!empty($gumtheme_options['apple_ipad_pro_icon'])) echo "<link rel='apple-touch-icon' sizes='167x167' href='".$gumtheme_options['apple_ipad_pro_icon']."'/>\n";

}

function gum_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		// This is an example of how to include a plugin bundled with a theme.
		array(
			'name'               => 'Gumthemes plugin', // The plugin name.
			'slug'               => 'gumtheme', // The plugin slug (typically the folder name).
			'source'             => 'https://gumtheme.com', // The plugin source.
			'required'           => true, // If false, the plugin is only 'recommended' instead of required.
			'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
			'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			'external_url'       => 'https://gumtheme.com', // If set, overrides default API URL and points to an external URL.
			'is_callable'        => '', // If set, this callable will be be checked for availability to determine if a plugin is active.
			'source_type'		=> 'gumtheme'
		),



	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'gumtheme',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => 'You can download Gumthemes plugin from your <a href="https://gumtheme.com">gumtheme account</a> or please contact us if you need any help.',                      // Message to output right before the plugins table.

	);

	tgmpa( $plugins, $config );
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
